@@ -8,6 +8,7 @@ from lxml import etree
 from lxml.etree import tostring
 
 from reqif.cli.cli_arg_parser import AnonimizeCommandConfig
+from reqif.helpers.lxml import stringify_namespaced_children
 from reqif.models.error_handling import ReqIFXMLParsingError
 from reqif.models.reqif_spec_object import ReqIFSpecObject, SpecObjectAttribute
 from reqif.models.reqif_specification import ReqIFSpecification
@@ -37,7 +38,7 @@ class AnonymizeCommand:
         output = AnonymizeCommand._anonymize(config)
         output_file = config.output_file
         output_dir = os.path.dirname(output_file)
-        if not os.path.isdir(output_dir):
+        if len(output_dir) > 0 and not os.path.isdir(output_dir):
             print(  # noqa: T201
                 f"error: output directory does not exist: {output_file}"
             )
@@ -105,11 +106,14 @@ class AnonymizeCommand:
             "//reqif:ATTRIBUTE-VALUE-XHTML/reqif:THE-VALUE", namespaces=fixns
         )
         for xml_attribute_value_xhtml in xml_attribute_value_xhtmls:
-            xml_attribute_value_xhtml.text = anonymize_string(
-                xml_attribute_value_xhtml.text
+            xml_attribute_value_xhtml_text: str = stringify_namespaced_children(
+                xml_attribute_value_xhtml
             )
             for child in list(xml_attribute_value_xhtml):
                 xml_attribute_value_xhtml.remove(child)
+            xml_attribute_value_xhtml.text = anonymize_string(
+                xml_attribute_value_xhtml_text
+            )
 
         return str(
             tostring(
