@@ -12,6 +12,7 @@ from reqif.parsers.spec_hierarchy_parser import (
 from reqif.parsers.spec_object_parser import (
     ATTRIBUTE_DATE_TEMPLATE,
     ATTRIBUTE_XHTML_TEMPLATE,
+    ATTRIBUTE_STRING_TEMPLATE,
 )
 
 
@@ -94,7 +95,6 @@ class ReqIFSpecificationParser:
                 elif xml_attribute.tag == "ATTRIBUTE-VALUE-XHTML":
                     the_value = xml_attribute.find("THE-VALUE")
                     attribute_value = stringify_namespaced_children(the_value)
-                    attribute_value = attribute_value.strip()
                     attribute_name = (
                         xml_attribute.find("DEFINITION")
                         .find("ATTRIBUTE-DEFINITION-XHTML-REF")
@@ -185,8 +185,18 @@ class ReqIFSpecificationParser:
                                     definition_ref=xml_attribute.definition_ref,
                                     value=xml_attribute.value,
                                 )
+                            elif (
+                                xml_attribute.attribute_type
+                                == SpecObjectAttributeType.STRING
+                            ):
+                                output += ATTRIBUTE_STRING_TEMPLATE.format(
+                                    definition_ref=xml_attribute.definition_ref,
+                                    value=xml_attribute.value,
+                                )
                             else:
-                                raise NotImplementedError(xml_attribute)
+                                raise NotImplementedError(
+                                    xml_attribute, xml_attribute.attribute_type
+                                )
                         output += "          </VALUES>\n"
         output += "        </SPECIFICATION>\n"
 
